@@ -1,10 +1,10 @@
-# @(#)$Id: Validation.pm 152 2012-05-02 14:07:33Z pjf $
+# @(#)$Id: Validation.pm 153 2012-06-11 17:07:21Z pjf $
 
 package Data::Validation;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.7.%d', q$Rev: 152 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 153 $ =~ /\d+/gmx );
 
 use Moose;
 use Data::Validation::Constraints;
@@ -143,7 +143,7 @@ sub _validate {
 # Private subroutines
 
 sub __get_methods {
-   return split q( ), $_[ 0 ];
+   return split q( ), $_[ 0 ] || q();
 }
 
 sub __should_compare {
@@ -166,7 +166,7 @@ Data::Validation - Filter and check data values
 
 =head1 Version
 
-0.7.$Rev: 152 $
+0.8.$Rev: 153 $
 
 =head1 Synopsis
 
